@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -52,6 +24,7 @@ package com.openexchange.admin.user.copy.rmi.impl;
 import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.java.Autoboxing.i;
 import java.rmi.RemoteException;
+import java.sql.SQLException;
 import com.openexchange.admin.daemons.AdminDaemon;
 import com.openexchange.admin.rmi.dataobjects.Context;
 import com.openexchange.admin.rmi.dataobjects.Credentials;
@@ -69,13 +42,13 @@ import com.openexchange.admin.rmi.impl.BasicAuthenticator;
 import com.openexchange.admin.rmi.impl.OXCommonImpl;
 import com.openexchange.admin.storage.utils.Filestore2UserUtil;
 import com.openexchange.admin.user.copy.rmi.OXUserCopyInterface;
+import com.openexchange.database.Databases;
+import com.openexchange.exception.ExceptionUtils;
 import com.openexchange.exception.OXException;
 import com.openexchange.user.copy.UserCopyService;
 
 public class OXUserCopy extends OXCommonImpl implements OXUserCopyInterface {
 
-    private static final String THE_GIVEN_SOURCE_USER_OBJECT_IS_NULL = "The given source user object is null";
-
     private final static org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(OXUserCopy.class);
 
     private final UserCopyService service;
@@ -90,7 +63,7 @@ public class OXUserCopy extends OXCommonImpl implements OXUserCopyInterface {
         try {
             doNullCheck(user);
         } catch (InvalidDataException e2) {
-            final InvalidDataException invalidDataException = new InvalidDataException(THE_GIVEN_SOURCE_USER_OBJECT_IS_NULL);
+            final InvalidDataException invalidDataException = new InvalidDataException("The given source user object is null");
             LOG.error(invalidDataException.getMessage(), invalidDataException);
             throw invalidDataException;
         }
@@ -139,14 +112,21 @@ public class OXUserCopy extends OXCommonImpl implements OXUserCopyInterface {
         int dstContextId = i(dest.getId());
         int srcUserId = i(user.getId());
 
-        final int newUserId;
-        try {
-            newUserId = service.copyUser(srcContextId, dstContextId, srcUserId);
-        } catch (OXException e) {
-            LOG.error("", e);
-            final StorageException storageException = new StorageException(e.getMessage());
-            setStackTraceSafe(storageException, e);
-            throw new StorageException(e.getMessage());
+        int newUserId = 0;
+        while (newUserId == 0) {
+            try {
+                newUserId = service.copyUser(srcContextId, dstContextId, srcUserId);
+            } catch (OXException e) {
+                SQLException optSqlException = ExceptionUtils.extractFrom(e, SQLException.class);
+                if (Databases.isTransactionRollbackException(optSqlException) == false) {
+                    LOG.error("", e);
+                    final StorageException storageException = new StorageException(e.getMessage());
+                    setStackTraceSafe(storageException, e);
+                    throw new StorageException(e.getMessage());
+                }
+                // Try again..
+                LOG.error("Going to repeat user-copy invocation for user {} from Context {} to Context {}", user.getId(), src.getId(), dest.getId(), e);
+            }
         }
 
         try {
@@ -160,7 +140,7 @@ public class OXUserCopy extends OXCommonImpl implements OXUserCopyInterface {
         return new User(newUserId);
     }
 
-    private void setStackTraceSafe(final Exception dest, final Exception src) {
+    private static void setStackTraceSafe(final Exception dest, final Exception src) {
         try {
             dest.setStackTrace(src.getStackTrace());
         } catch (Exception x) {
@@ -168,7 +148,7 @@ public class OXUserCopy extends OXCommonImpl implements OXUserCopyInterface {
         }
     }
 
-    private final void contextcheck(final Context ctx, final String type) throws InvalidDataException {
+    private static void contextcheck(final Context ctx, final String type) throws InvalidDataException {
         if (null == ctx || null == ctx.getId()) {
             final InvalidDataException e = new InvalidDataException("Client sent invalid " + type + " context data object");
             LOG.error("", e);
