@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -68,6 +40,7 @@ import com.openexchange.chronos.Alarm;
 import com.openexchange.chronos.Attendee;
 import com.openexchange.chronos.AttendeeField;
 import com.openexchange.chronos.CalendarUser;
+import com.openexchange.chronos.CalendarUserType;
 import com.openexchange.chronos.Event;
 import com.openexchange.chronos.Organizer;
 import com.openexchange.chronos.ResourceId;
@@ -183,7 +156,7 @@ public class ChronosCopyTask implements CopyUserTaskService {
         Map<String, List<Attendee>> attendees = exchangeAttendeesIds(folderMapping, eventAttendeeMapping, dstEventMapping, dstUsrId, srcUsrId);
         insertDestinationAttendees(attendees);
         //Alarms
-        Map<String, Map<Integer, List<Alarm>>> alarmByEventByUser = exchangeAlarmIds(alarmByEvent, dstEventMapping, srcUsrId, dstUsrId);
+        Map<String, Map<Integer, List<Alarm>>> alarmByEventByUser = exchangeAlarmIds(alarmByEvent, dstEventMapping, dstUsrId);
         insertDestinationAlarms(new ArrayList<>(dstEventMapping.values()), alarmByEventByUser, attendees);
         //AlarmTrigger
         insertDestinationAlarmTriggers(alarmByEventByUser, new ArrayList<>(dstEventMapping.values()));
@@ -284,9 +257,12 @@ public class ChronosCopyTask implements CopyUserTaskService {
                     if (organizer.getEntity() == srcUsrId) {
                         organizer.setEntity(dstUsrId);
                         organizer.setUri(calendarUser.getUri());
-                    } else {
-                        organizer.setUri(organizer.getEMail());
+                        organizer.setEMail(calendarUser.getEMail());
+                    } else if (CalendarUtils.isInternal(organizer, CalendarUserType.INDIVIDUAL)) {
                         organizer.setEntity(0);
+                        if (null == CalendarUtils.optEMailAddress(organizer.getUri()) && Strings.isNotEmpty(organizer.getEMail())) {
+                            organizer.setUri(CalendarUtils.getURI(organizer.getEMail()));
+                        }
                     }
                 }
                 srcEvent.setId(dstEventId);
@@ -318,12 +294,20 @@ public class ChronosCopyTask implements CopyUserTaskService {
             String srcEventId = entry.getKey();
             List<Attendee> attendees = new ArrayList<>(entry.getValue().size());
             for (Attendee attendee : entry.getValue()) {
-                //setters for attendee values
-                if (attendee.getEntity() == srcUsrId) {
-                    attendee.setFolderId(getDestinationFolder(folderMapping, Integer.parseInt(attendee.getFolderId())));
-                    attendee.setEntity(dstUsrId);
-                } else if (CalendarUtils.isExternalUser(attendee)) {
-                    attendee.setFolderId(null);
+                if (CalendarUtils.isInternal(attendee)) {
+                    if (false == CalendarUserType.INDIVIDUAL.matches(attendee.getCuType())) {
+                        continue; // skip internal group- and resource attendees
+                    }
+                    if (srcUsrId == attendee.getEntity()) {
+                        // exchange with destination user
+                        attendee.setFolderId(getDestinationFolder(folderMapping, Integer.parseInt(attendee.getFolderId())));
+                        attendee.setEntity(dstUsrId);
+                    } else {
+                        // turn into external calendar user
+                        attendee.setFolderId(null);
+                        attendee.setEntity(0);
+                    }
+                    attendee.setMember(null);
                 }
                 attendees.add(attendee);
             }
@@ -333,22 +317,27 @@ public class ChronosCopyTask implements CopyUserTaskService {
         return dstAttendees;
     }
 
-    private Map<String, Map<Integer, List<Alarm>>> exchangeAlarmIds(Map<String, List<Alarm>> alarmByEvent, Map<String, Event> dstEventMapping, int srcUsrId, int dstUsrId) throws OXException {
+    private Map<String, Map<Integer, List<Alarm>>> exchangeAlarmIds(Map<String, List<Alarm>> alarmByEvent, Map<String, Event> dstEventMapping, int dstUsrId) throws OXException {
         Map<String, Map<Integer, List<Alarm>>> alarmsByUserByEventId = new HashMap<>(alarmByEvent.size());
         Map<Integer, List<Alarm>> alarmsByUser = null;
         List<Alarm> alarmList;
         for (Entry<String,  List<Alarm>> alarmsPerEvent : alarmByEvent.entrySet()) {
-                alarmsByUser = new HashMap<>(1);
-                alarmList = new ArrayList<>(alarmsPerEvent.getValue().size());
-                for (Alarm alarm : alarmsPerEvent.getValue()) {
-                    alarm.setId(dstCalendarStorage.getAlarmStorage().nextId());
-                    alarm.setTimestamp(System.currentTimeMillis());
-                    //add to list
-                    alarmList.add(alarm);
-                }
-                //add to inner map
-                alarmsByUser.put(I(dstUsrId), alarmList);
-                alarmsByUserByEventId.put(dstEventMapping.get(alarmsPerEvent.getKey()).getId(), alarmsByUser);
+            Event dstEvent = dstEventMapping.get(alarmsPerEvent.getKey());
+            if (null == dstEvent) {
+                continue; // skip alarms of events that weren't copied
+            }
+
+            alarmsByUser = new HashMap<>(1);
+            alarmList = new ArrayList<>(alarmsPerEvent.getValue().size());
+            for (Alarm alarm : alarmsPerEvent.getValue()) {
+                alarm.setId(dstCalendarStorage.getAlarmStorage().nextId());
+                alarm.setTimestamp(System.currentTimeMillis());
+                //add to list
+                alarmList.add(alarm);
+            }
+            //add to inner map
+            alarmsByUser.put(I(dstUsrId), alarmList);
+            alarmsByUserByEventId.put(dstEvent.getId(), alarmsByUser);
         }
         return alarmsByUserByEventId;
     }
